@@ -28,6 +28,11 @@
 
 QTEST_MAIN(AddressTest)
 
+void AddressTest::initTestCase()
+{
+     setenv("LANG", "C", 1);
+}
+
 void AddressTest::emptyTest()
 {
     KContacts::Address address;
